library calendar_data_timeline;

import 'package:calendar_data_timeline/widget/helper_widgets.dart';
import 'package:flutter/material.dart';
import 'package:calendar_data_timeline/views/export_all.dart';
import 'package:calendar_data_timeline/models/export_all.dart';
export 'package:calendar_data_timeline/models/export_all.dart';

class CalendarDataTimeline extends StatefulWidget {
  final List<CalendarContent> data;

  ///List of Instance CalendarContent which will be used as the in body
  final HeaderSettings settings;

  ///Instance of HeaderSettings
  final BodySettings bodySettings;

  ///Instance of BodySettings
  final Color? sundayColor;

  /// Color choice for sunday color, leave it null if you want to highlight sunday as well.
  CalendarDataTimeline(
      {required this.data,
      required this.settings,
      required this.bodySettings,
      this.sundayColor});

  @override
  _CalendarDataTimelineState createState() => _CalendarDataTimelineState();
}

class _CalendarDataTimelineState extends State<CalendarDataTimeline>
    with WidgetHelpers {
  /// alpha scroll controller (basis)
  final ScrollController _parentController = new ScrollController();

  /// child scroll controller (dependent to the alpha)
  final ScrollController _childController = new ScrollController();

  /// Instance of Calendar control
  late final CalendarControl _controlCenter = new CalendarControl(
    locale: widget.settings.locale,
  );

  /// instance of calendar header
  late final CalendarHeader _header;

  /// instance of calendar body
  late final CalendarBody _body = new CalendarBody(
    controller: _childController,
    bodySettings: widget.bodySettings,
    data: widget.data,
    sundayColor: widget.sundayColor,
  );

  @override
  void initState() {
    _parentController.addListener(() {
      _childController.jumpTo(_parentController.offset);
    });
    _header = new CalendarHeader(
      settings: widget.settings,
      controller: _parentController,
      sundayColor: widget.sundayColor,
    );
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    try {
      return Material(
        child: LayoutBuilder(
          builder: (context, constraint) => Container(
            width: constraint.maxWidth,
            height: constraint.maxHeight,
            child: Column(
              children: [
                _controlCenter,

                ///Calendar header
                _header,

                ///Calendar Body
                Expanded(child: _body)
              ],
            ),
          ),
        ),
      );
    } catch (e) {
      return Center(
        child: Text("Please wait..."),
      );
    }
  }
}
